@@ -43,7 +43,7 @@ describe('ncp / error / dest-permission', () => {
 
     ncp(src, subdest, err => {
       assert(err)
-      assert.equal(err.code, 'EACCES')
+      assert.strictEqual(err.code, 'EACCES')
       done()
     })
   })
