@@ -67,11 +67,11 @@ describe('symlink-type', () => {
       it(`should return '${JSON.stringify(expectedRelativePaths)}' when src '${args[0]}' and dst is '${args[1]}'`, done => {
         const callback = (err, relativePaths) => {
           if (err) done(err)
-          assert.deepEqual(relativePaths, expectedRelativePaths)
+          assert.deepStrictEqual(relativePaths, expectedRelativePaths)
           done()
         }
         args.push(callback)
-        return symlinkPaths.apply(null, args)
+        return symlinkPaths(...args)
       })
     })
   })
@@ -81,8 +81,8 @@ describe('symlink-type', () => {
       const args = test[0].slice(0)
       const expectedRelativePaths = test[1]
       it(`should return '${JSON.stringify(expectedRelativePaths)}' when src '${args[0]}' and dst is '${args[1]}'`, () => {
-        const relativePaths = symlinkPathsSync.apply(null, args)
-        assert.deepEqual(relativePaths, expectedRelativePaths)
+        const relativePaths = symlinkPathsSync(...args)
+        assert.deepStrictEqual(relativePaths, expectedRelativePaths)
       })
     })
   })
