@@ -13,7 +13,7 @@ describe('json', () => {
   let TEST_DIR
 
   beforeEach(done => {
-    TEST_DIR = path.join(os.tmpdir(), 'fs-extra')
+    TEST_DIR = path.join(os.tmpdir(), 'fs-extra-output-json-sync')
     fse.emptyDir(TEST_DIR, done)
   })
 
@@ -28,7 +28,7 @@ describe('json', () => {
       assert(fs.existsSync(file))
       const newData = JSON.parse(fs.readFileSync(file, 'utf8'))
 
-      assert.equal(data.name, newData.name)
+      assert.strictEqual(data.name, newData.name)
     })
 
     describe('> when an option is passed, like JSON replacer', () => {
@@ -42,7 +42,7 @@ describe('json', () => {
         outputJsonSync(file, data, { replacer })
         const newData = JSON.parse(fs.readFileSync(file, 'utf8'))
 
-        assert.equal(newData.name, 'Jon Paul')
+        assert.strictEqual(newData.name, 'Jon Paul')
       })
     })
   })
