@@ -43,9 +43,9 @@ describe('mkdirp / chmod', () => {
         assert.ok(stat && stat.isDirectory(), 'should be directory')
 
         if (os.platform().indexOf('win') === 0) {
-          assert.equal(stat && stat.mode & o777, o666, 'windows shit')
+          assert.strictEqual(stat && stat.mode & o777, o666, 'windows shit')
         } else {
-          assert.equal(stat && stat.mode & o777, mode, 'should be 0744')
+          assert.strictEqual(stat && stat.mode & o777, mode, 'should be 0744')
         }
 
         done()
