@@ -33,9 +33,9 @@ describe('mkdirp / perm_sync', () => {
         assert.ifError(err)
 
         if (os.platform().indexOf('win') === 0) {
-          assert.equal(stat.mode & o777, o666)
+          assert.strictEqual(stat.mode & o777, o666)
         } else {
-          assert.equal(stat.mode & o777, o755)
+          assert.strictEqual(stat.mode & o777, o755)
         }
 
         assert.ok(stat.isDirectory(), 'target not a directory')
