@@ -28,7 +28,7 @@ describe('mkdirp / race', () => {
         ps.push(dir)
       }
 
-      file = path.join.apply(path, ps)
+      file = path.join(...ps)
       done()
     })
   })
@@ -51,9 +51,9 @@ describe('mkdirp / race', () => {
             assert.ifError(err)
 
             if (os.platform().indexOf('win') === 0) {
-              assert.equal(stat.mode & o777, o666)
+              assert.strictEqual(stat.mode & o777, o666)
             } else {
-              assert.equal(stat.mode & o777, o755)
+              assert.strictEqual(stat.mode & o777, o755)
             }
 
             assert.ok(stat.isDirectory(), 'target not a directory')
