@@ -30,10 +30,10 @@ describe('mkdirp / return value', () => {
     // already exist, since every other test makes things in there.
     fse.mkdirp(file, (err, made) => {
       assert.ifError(err)
-      assert.equal(made, dir + x)
+      assert.strictEqual(made, dir + x)
       fse.mkdirp(file, (err, made) => {
         assert.ifError(err)
-        assert.equal(made, null)
+        assert.strictEqual(made, null)
         done()
       })
     })
