@@ -47,9 +47,9 @@ describe('mkdirp / sync', () => {
         assert.ifError(err)
         // http://stackoverflow.com/questions/592448/c-how-to-set-file-permissions-cross-platform
         if (os.platform().indexOf('win') === 0) {
-          assert.equal(stat.mode & o777, o666)
+          assert.strictEqual(stat.mode & o777, o666)
         } else {
-          assert.equal(stat.mode & o777, o755)
+          assert.strictEqual(stat.mode & o777, o755)
         }
 
         assert.ok(stat.isDirectory(), 'target not a directory')
