@@ -47,7 +47,7 @@ describe('mkdirp', () => {
             assert.ok(ex, 'file created')
             fs.stat(_rndDir, (err, stat) => {
               assert.ifError(err)
-              assert.equal(stat.mode & o777, o777 & (~process.umask()))
+              assert.strictEqual(stat.mode & o777, o777 & (~process.umask()))
               assert.ok(stat.isDirectory(), 'target not a directory')
               done()
             })
@@ -71,7 +71,7 @@ describe('mkdirp', () => {
           assert.ok(ex, 'file created')
           fs.stat(_rndDir, (err, stat) => {
             assert.ifError(err)
-            assert.equal(stat.mode & o777, (o777 & (~process.umask())))
+            assert.strictEqual(stat.mode & o777, (o777 & (~process.umask())))
             assert.ok(stat.isDirectory(), 'target not a directory')
             done()
           })
